@@ -3,6 +3,7 @@ This module contains format variable for all the annotations
 """
 
 from collections import namedtuple
+from enum import Enum
 
 __all__ = [
     "Layer",
@@ -30,7 +31,7 @@ __all__ = [
 ]
 
 
-class AnnType:
+class AnnType(Enum):
     book_title = "BookTitle"
     sub_title = "SubTitle"
     book_number = "BookNumber"
@@ -54,7 +55,6 @@ class AnnType:
     durchen = "Durchen"
     footnote = "Footnote"
 
-
 class _attr_names:
     # Layer
     ID = "id"  # Uique id for annotation of specific Pecha or Abstract work. type: str
