@@ -2,18 +2,21 @@
 """
 import gzip
 import io
-import urllib
-import requests
 import shutil
+import urllib
 from collections import defaultdict
 from pathlib import Path
 from typing import Dict
 
+import requests
 import yaml
 from git import GIT_OK, Repo
 from git.cmd import GitCommandError
 
 from openpecha import config, storages
+from openpecha.core.layer import LayerEnum
+from openpecha.formatters.layers import AnnType
+from openpecha.core import metadata
 from openpecha.exceptions import PechaNotFound
 from openpecha.github_utils import create_release
 from openpecha.storages import GithubStorage, setup_auth_for_old_repo
@@ -31,6 +34,15 @@ try:
 except (ImportError, AttributeError):
     yaml_dumper = yaml.SafeDumper
 
+def simple_enum_to_yaml(representer, node):
+    return representer.represent_data(node.value)
+
+yaml_dumper.add_multi_representer(LayerEnum, simple_enum_to_yaml)
+yaml_dumper.add_multi_representer(AnnType, simple_enum_to_yaml)
+yaml_dumper.add_multi_representer(metadata.InitialCreationType, simple_enum_to_yaml)
+yaml_dumper.add_multi_representer(metadata.CopyrightStatus, simple_enum_to_yaml)
+yaml_dumper.add_multi_representer(metadata.LicenseType, simple_enum_to_yaml)
+
 def gzip_str(string_):
     # taken from https://gist.github.com/Garrett-R/dc6f08fc1eab63f94d2cbb89cb61c33d
     out = io.BytesIO()
@@ -46,7 +58,7 @@ def _mkdir(path):
         return path
     path.mkdir(exist_ok=True, parents=True)
     return path
-    
+
 def ocr_result_input(path):
     return path
 
@@ -118,6 +130,10 @@ def _eval_branch(repo, branch):
 
 
 def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
+    # resolve defaults kwargs
+    needs_update = needs_update if needs_update is not None else True
+    branch = branch if branch is not None else "main"
+
     # clone the repo
     pecha_url = f"{config.GITHUB_ORG_URL}/{pecha_id}.git"
     if out_path:
@@ -132,10 +148,9 @@ def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
         branch = _eval_branch(repo, branch)
         repo.git.checkout(branch)
         if needs_update:
-            print(INFO.format(f"Updating {pecha_id} ..."))
+            repo.git.config("pull.rebase", "false")
             repo.git.pull("origin", branch)
     else:
-        print(INFO.format(f"Downloading {pecha_id} ..."))
         try:
             Repo.clone_from(pecha_url, str(pecha_path))
         except GitCommandError:
@@ -152,7 +167,7 @@ def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
 
 
 def download_pecha_assets(pecha_id: str, asset_type:str, download_dir:Path):
-    """Download pecha assets from latest release 
+    """Download pecha assets from latest release
 
     Args:
         pecha_id (str): pecha id
@@ -162,7 +177,7 @@ def download_pecha_assets(pecha_id: str, asset_type:str, download_dir:Path):
     Returns:
         Path: zip file path of downloaded asset
     """
-    
+
 
     response = requests.get(f"https://api.github.com/repos/OpenPecha-data/{pecha_id}/releases/latest")
     res = response.json()
@@ -176,4 +191,4 @@ def download_pecha_assets(pecha_id: str, asset_type:str, download_dir:Path):
 
     zip_asset_file_path.write_bytes(assets)
 
-    return zip_asset_file_path
\ No newline at end of file
+    return zip_asset_file_path
